package com.ucalc.lib;

public class uCalcImport {
   static {
      System.loadLibrary("uCalcAndroid");
   }

   public static native double Evaluate(int ExprHandle);
   public static native double EvaluateNTE(int ExprHandle);
   public static native int EvaluateInt32(int ExprHandle);
   public static native String EvaluateStr(int ExprHandle);
   public static native int EvaluateVoid(int ExprHandle);
   public static native void Execute(int ExprHandle);
   public static native void ReleaseExpr(int ExprHandle);
   public static native int Handle1Overload1ParsedExpr(int ExprHandle);
   public static native int ElementCount(int ItemHandle);
   public static native int GetDataType(int ItemHandle);
   public static native int FunctionAddress(int ItemHandle);
   public static native int IsProperty(int ItemHandle, int ItemProperty);
   public static native String Name1Overload1Item(int ItemHandle);
   public static native int NextOverload(int ItemHandle);
   public static native int Precedence1Overload1Item(int ItemHandle);
   public static native void ReleaseItem(int ItemHandle);
   public static native void Rename(int ItemHandle, String NewName);
   public static native void SetVariableValue(int ItemHandle, double Value);
   public static native void SetVariableValueAny(int ItemHandle, String Value);
   public static native void SetVariableValueByte(int ItemHandle, byte Value);
   public static native void SetVariableValueInt16(int ItemHandle, short  Value);
   public static native void SetVariableValueInt32(int ItemHandle, int Value);
   public static native void SetVariableValueInt64(int ItemHandle, long  Value);
   public static native void SetVariableValueSng(int ItemHandle, float Value);
   public static native void SetVariableValueDbl(int ItemHandle, double Value);
   public static native void SetVariableValueStr(int ItemHandle, String Value);
   public static native void SetVariableValuePtr(int ItemHandle, int Value);
   public static native void SetVariableValueByPtr(int ItemHandle, int Value);
   public static native String Text(int ItemHandle);
   public static native int GetuCalc1Overload1Item(int ItemHandle);
   public static native double Value(int ItemHandle);
   public static native byte ValueByte(int ItemHandle);
   public static native short ValueInt16(int ItemHandle);
   public static native int ValueInt32(int ItemHandle);
   public static native long ValueInt64(int ItemHandle);
   public static native float ValueSng(int ItemHandle);
   public static native double ValueDbl(int ItemHandle);
   public static native String ValueStr(int ItemHandle);
   public static native int ValuePtr(int ItemHandle);
   public static native int ValueAddr(int ItemHandle);
   public static native int Handle1Overload1Item(int ItemHandle);
   public static native double Arg(int ExprPartHandle, int Index);
   public static native int ArgCount(int ExprPartHandle);
   public static native int ArgObj(int ExprPartHandle, int Index);
   public static native int ArgAddr(int ExprPartHandle, int Index);
   public static native int ArgExpr(int ExprPartHandle, int Index);
   public static native int ArgInt32(int ExprPartHandle, int Index);
   public static native long ArgInt64(int ExprPartHandle, int Index);
   public static native int ArgPtr(int ExprPartHandle, int Index);
   public static native String ArgStr(int ExprPartHandle, int Index);
   public static native void Return(int ExprPartHandle, double Value);
   public static native void ReturnInt32(int ExprPartHandle, int Value);
   public static native void ReturnInt64(int ExprPartHandle, long  Value);
   public static native void ReturnPtr(int ExprPartHandle, int Value);
   public static native void ReturnStr(int ExprPartHandle, String Value);
   public static native int ErrorRaise(int ExprPartHandle, int ErrNumber);
   public static native int ErrorRaiseMessage(int ExprPartHandle, String ErrMessage);
   public static native int GetuCalc1Overload1Callback(int ExprPartHandle);
   public static native int Handle1Overload1Callback(int ExprPartHandle);
   public static native int OpItem(int ExprPartHandle);
   public static native int AllocArray(int DataTypeHandle, int ArraySize);
   public static native int AllocByPtr(int DataTypeHandle, int ValuePtr);
   public static native int AllocScalar(int DataTypeHandle, String Value);
   public static native int ByteSize(int DataTypeHandle);
   public static native int Index(int DataTypeHandle);
   public static native int GetItem(int DataTypeHandle);
   public static native String Name1Overload1DataType(int DataTypeHandle);
   public static native void ReleaseArray(int DataTypeHandle, int ValuePtr);
   public static native void ReleaseScalar(int DataTypeHandle, int ValuePtr);
   public static native void ResetArray(int DataTypeHandle, int ValuePtr);
   public static native void ResetScalar(int DataTypeHandle, int ValuePtr);
   public static native void SetArray(int DataTypeHandle, int Destination, int Source, int Index);
   public static native void SetScalar(int DataTypeHandle, int Destination, int Source);
   public static native void SwapScalarValues(int DataTypeHandle, int ValuePtrA, int ValuePtrB);
   public static native String ToString1Overload1DataType11ByPtr(int DataTypeHandle, int ValuePtr);
   public static native String ToString1Overload1DataType11ByStr(int DataTypeHandle, String Value);
   public static native int Handle1Overload1DataType(int DataTypeHandle);
   public static native int Active(int RuleHandle, int TrueFalse);
   public static native int FindPart(int RuleHandle, String Pattern);
   public static native int FromPart(int RuleHandle, String Pattern);
   public static native int ToPart(int RuleHandle, String Pattern);
   public static native int CaseSensitive(int RuleHandle, int TrueFalse);
   public static native int IgnoreInnerPatterns(int RuleHandle, int TrueFalse);
   public static native int WhitespaceSensitive(int RuleHandle, int TrueFalse);
   public static native int BracketSensitive(int RuleHandle, int TrueFalse);
   public static native int Comment1Overload1uCalcTransform1RuleClass(int RuleHandle, String CommentStr);
   public static native int LocalTransform(int RuleHandle);
   public static native int Maximum(int RuleHandle, int Value);
   public static native int MaximumHard(int RuleHandle, int Value);
   public static native int Minimum(int RuleHandle, int Value);
   public static native int MinimumHard(int RuleHandle, int Value);
   public static native int Precedence(int RuleHandle, int Value);
   public static native int QuoteSensitive(int RuleHandle, int TrueFalse);
   public static native String ReplacementText(int RuleHandle);
   public static native int StartAfter(int RuleHandle, int Value);
   public static native int StopAfter(int RuleHandle, int Value);
   public static native int SkipOver(int RuleHandle, int TrueFalse);
   public static native int RewindOnChange(int RuleHandle, int TrueFalse);
   public static native int ParseAgainMax(int RuleHandle, int TrueFalse, int RaiseError);
   public static native int RightToLeft(int RuleHandle, int TrueFalse);
   public static native void ReleaseRule(int RuleHandle);
   public static native int Comment1Overload1uCalcTransform1Tokens(int TokensHandle, String CommentStr);
   public static native int Import1Overload1uCalcTransform1Tokens11Obj(int TokensHandle, int FromTokenList);
   public static native int Import1Overload1uCalcTransform1Tokens11File(int TokensHandle, String TokenFile);
   public static native int Define1Overload1uCalcTransform1Tokens(int TokensHandle, String TokenDef, int TokenType, String CloseBracket, int SubMatch, int RegExGrammar);
   public static native int Comment1Overload1uCalcTransform(int TransformHandle, String CommentStr);
   public static native int DefineRule(int TransformHandle, String Comment, String FindStr, String ToStr, int Min, int Max, int MinHard, int MaxHard, int Precedence, int StartAfter, int StopAfter, int SkipOver, int RewindOnChange, int CaseSensitive, int BracketSensitive, int QuoteSensitive, int RightToLeft);
   public static native int DefineToken(int TransformHandle, String TokenDef, int TokenType, String CloseBracket, int SubMatch, int RegExGrammar);
   public static native int GetTokens(int TransformHandle);
   public static native int FromTo(int TransformHandle, String FromStr, String ToStr);
   public static native int Import1Overload1uCalcTransform(int TransformHandle, String FileName);
   public static native int ListPrefix(int TransformHandle, String Prefix);
   public static native int ListPostfix(int TransformHandle, String Postfix);
   public static native int ListSeparator(int TransformHandle, String Separator);
   public static native int ListDelimiters(int TransformHandle, String Prefix, String Separator, String Postfix);
   public static native int MathParser(int TransformHandle, int FMP);
   public static native int NewPass(int TransformHandle, int Share);
   public static native int Pass(int TransformHandle, int Index, int Share);
   public static native int Reset(int TransformHandle, int ResetOption);
   public static native String ResultStr(int TransformHandle);
   public static native int Transform(int TransformHandle);
   public static native String Expand(int TransformHandle, String Expression);
   public static native String ExpandWithSteps(int TransformHandle, String Expression, String Separator, String Prefix, String Postfix);
   public static native int SetInput(int TransformHandle, String InputStr);
   public static native int SetInputByRef(int TransformHandle, int InputStr);
   public static native int SetParser(int TransformHandle, int FMP);
   public static native int SetProperties(int TransformHandle, int TransformProperties);
   public static native int WasModified(int TransformHandle);
   public static native void ReleaseTransform(int TransformHandle);
   public static native int GetRule(int TransformHandle, int Index);
   public static native int RulesDefault(int TransformHandle);
   public static native int RulesOverall(int TransformHandle);
   public static native int CharLengthOfTokens(int StringLibHandle, int StartIndex, int Count);
   public static native int TokenCount(int StringLibHandle);
   public static native int TokenType(int StringLibHandle, int Index);
   public static native int Compare(int StringLibHandle, String OtherString, int IndexA, int IndexB, int Length   1);
   public static native int TokenIndexAtChar(int StringLibHandle, int Index);
   public static native int NthToken(int StringLibHandle, int Index, int SubMatch);
   public static native int BracketMatch(int StringLibHandle, int Index);
   public static native int BracketGrouping(int StringLibHandle, int Index);
   public static native int BracketGroupingInner(int StringLibHandle, int Index);
   public static native int StrPos(int StringLibHandle);
   public static native int StrLen(int StringLibHandle);
   public static native int StrCharPos(int StringLibHandle);
   public static native int StrCharLen(int StringLibHandle);
   public static native String GetStr(int StringLibHandle);
   public static native int SetStr(int StringLibHandle, String StringValue);
   public static native int ResetPos(int StringLibHandle, int StartPos, int Length   1);
   public static native int AutoResetPos(int StringLibHandle, int TrueFalse);
   public static native int Find(int StringLibHandle, String Pattern, int Nth);
   public static native int UpTo(int StringLibHandle, String Pattern, int Nth);
   public static native int Onward(int StringLibHandle, String Pattern, int Nth);
   public static native int Before(int StringLibHandle, String Pattern, int Nth);
   public static native int After(int StringLibHandle, String Pattern, int Nth);
   public static native int Between(int StringLibHandle, String StartPattern, String StopPattern, int StartNth, int StopNth);
   public static native int SubString(int StringLibHandle, int StartPos, int Length   1);
   public static native int SelectFrom(int StringLibHandle, String Pattern, String ZoomIn);
   public static native int Replace(int StringLibHandle, String From_, String To_);
   public static native int IfX(int StringLibHandle, String Condition);
   public static native int Skip(int StringLibHandle, String Pattern);
   public static native int ToUpper(int StringLibHandle, String InnerStr, int Nth   1);
   public static native int ToLower(int StringLibHandle, String InnerStr, int Nth   1);
   public static native int ToList(int StringLibHandle);
   public static native int DoTransform(int StringLibHandle);
   public static native String Match(int StringLibHandle, int Index);
   public static native String MatchByParent(int StringLibHandle, int ParentIndex, int Index);
   public static native String SubMatch(int StringLibHandle, int Index);
   public static native int MatchCount(int StringLibHandle);
   public static native int Format(int StringLibHandle, String FormatPattern);
   public static native int AddErrorHandler(int uCalcHandle, int ErrorHandlerAddress, int Position);
   public static native int CreateuCalc(int uCalcHandle);
   public static native int DataTypeOfIndex(int uCalcHandle, int Index);
   public static native int Define1Overload1uCalc(int uCalcHandle, String Expression, int Address, int ExistingItem);
   public static native int DefineConstant(int uCalcHandle, String Definition, int VariableAddress);
   public static native int DefineDataType(int uCalcHandle, int TypeSize, int AllocArrayValue, int AllocScalar, int AllocScalarByPtr, int DeleteArray, int DeleteScalar, int ResetScalar, int ResetArray, int SetValueArray, int SetValueScalar, int SwapValues, int ToString);
   public static native int DefineFunction(int uCalcHandle, String Definition, int FunctionAddress);
   public static native int DefineOperator(int uCalcHandle, String Definition, int iPrecedence, int Grouping, int FunctionAddress);
   public static native int DefineVariable(int uCalcHandle, String Definition, int VariableAddress);
   public static native String ErrorExpression(int uCalcHandle);
   public static native int ErrorLocation(int uCalcHandle);
   public static native String ErrorMessage(int uCalcHandle, int Index);
   public static native int ErrorNumber(int uCalcHandle);
   public static native void ErrorResponse(int uCalcHandle, int Response);
   public static native String ErrorSymbol(int uCalcHandle);
   public static native void ErrorSetExpression(int uCalcHandle, String Expression);
   public static native double Eval(int uCalcHandle, String Expression);
   public static native String EvalStr(int uCalcHandle, String Expression);
   public static native int FPEnvClearException(int uCalcHandle, int Exceptions);
   public static native int FPEnvGetExceptionMask(int uCalcHandle);
   public static native int FPEnvRaiseException(int uCalcHandle, int Exception);
   public static native int FPEnvGetRounding(int uCalcHandle);
   public static native void FPEnvSetExceptionMask(int uCalcHandle, int Exceptions);
   public static native void FPEnvSetExceptionUnMask(int uCalcHandle, int Exceptions);
   public static native int FPEnvSetRounding(int uCalcHandle, int Direction);
   public static native void FPEnvToggleExceptionMask(int uCalcHandle, int Exception);
   public static native int HandleOf(int uCalcHandle, String ItemName, long  Properties, int SkipTransform);
   public static native int GetItemOf(int uCalcHandle, String ItemName, long  Properties, int SkipExpansion);
   public static native int GetItemOfProperty(int uCalcHandle, int Property_, int nth, String DataTypeName);
   public static native int License(int uCalcHandle, int LicenseType, int L1, int L2, int L3, int L4, int L5);
   public static native int NamespaceChild(int uCalcHandle, int nth);
   public static native int NamespaceChildCount(int uCalcHandle);
   public static native int NamespaceParent(int uCalcHandle, int Level);
   public static native int NamespaceSymbol(int uCalcHandle, int nth);
   public static native int NamespaceSymbolCount(int uCalcHandle);
   public static native int NewString(int uCalcHandle, String InitialString);
   public static native int NewTransform(int uCalcHandle);
   public static native int ParserTransform(int uCalcHandle);
   public static native int Parse(int uCalcHandle, String Expression, String DataType);
   public static native int Precedence1Overload1uCalc(int uCalcHandle, String Operator1, String Operator2);
   public static native long Properties(int uCalcHandle, int p1, int p2, int p3, int p4);
   public static native void ReleaseuCalc(int uCalcHandle);
   public static native void ResetOutput(int uCalcHandle);
   public static native int Default(int uCalcHandle);
   public static native int SetOutput1Overload1uCalc11Callback(int uCalcHandle, int FunctionAddress, String Properties);
   public static native int SetOutput1Overload1uCalc11NoCallback(int uCalcHandle, String Definition);
   public static native int CreateTransform(int uCalcHandle);
   public static native String ValueAt(int uCalcHandle, int ValuePtr, String DataType);
   public static native int Handle1Overload1uCalc(int uCalcHandle);
}